*************************************************************
:mod:`mopidy.mixers.nad` -- Hardware mixer for NAD amplifiers
*************************************************************

.. inheritance-diagram:: mopidy.mixers.nad

.. automodule:: mopidy.mixers.nad
    :synopsis: Hardware mixer for NAD amplifiers
    :members:
